@@ -16,5 +16,4 @@ import colorlog
 logger = colorlog.getLogger(logger.name)
 
 from .sequana_manager import SequanaManager, get_pipeline_location
-from .snaketools import (Module, PipelineManager, PipelineManagerDirectory,
-                         SequanaConfig)
+from .snaketools import Module, PipelineManager, PipelineManagerDirectory, SequanaConfig
