@@ -135,9 +135,7 @@ class SequanaManager:
             self.apptainer_prefix = self.options.apptainer_prefix
             self.local_apptainers = False
         else:  # pragma: no cover
-            self.apptainer_prefix = os.environ.get(
-                "SEQUANA_SINGULARITY_PREFIX", f"{self.workdir}/.sequana/apptainers"
-            )
+            self.apptainer_prefix = os.environ.get("SEQUANA_SINGULARITY_PREFIX", f"{self.workdir}/.sequana/apptainers")
             self.local_apptainers = True
 
     def exists(self, filename, exit_on_error=True, warning_only=False):  # pragma: no cover
@@ -190,7 +188,6 @@ class SequanaManager:
         logger.error(f"package provided ({self.name}) not installed.")
         raise PipetoolsException
 
-
     def _get_package_version(self):
         try:
             ver = pkg_resources.require("sequana_{}".format(self.name))[0].version
@@ -201,7 +198,7 @@ class SequanaManager:
 
     def _get_sequana_version(self):
         try:
-            ver = pkg_resources.require("sequana".format(self.name))[0].version
+            ver = pkg_resources.require(f"sequana.{self.name}")[0].version
             return ver
         except pkg_resources.DistributionNotFound:  # pragma: no cover
             return "not installed"
@@ -260,7 +257,7 @@ class SequanaManager:
 
             # finally, the prefix where images are stored
             if self.local_apptainers:
-                self.command += f" --singularity-prefix .sequana/apptainers"
+                self.command += " --singularity-prefix .sequana/apptainers"
             else:
                 self.command += f" --singularity-prefix {self.apptainer_prefix} "
 
@@ -489,16 +486,24 @@ class SequanaManager:
             fout.write(f"#!/bin/sh\nsnakemake -s {snakefilename} --unlock -j 1")
 
         # save environement
-        try:
+
+        if shutil.which("conda"):
             cmd = "conda list"
-            with open("{}/.sequana/env.yml".format(self.workdir), "w") as fout:
+            with open(f"{self.workdir}/.sequana/env.yml", "w") as fout:
                 subprocess.call(cmd.split(), stdout=fout)
             logger.debug("Saved your conda environment into env.yml")
-        except Exception:
-            cmd = "pip freeze"
-            with open("{}/.sequana/pip.yml".format(self.workdir), "w") as fout:
+        else:
+            with open(f"{self.workdir}/.sequana/env.yml", "w") as fout:
+                fout.write("conda not found")
+
+        if shutil.which("pip"):
+            cmd = f"{sys.executable} -m pip freeze"
+            with open(f"{self.workdir}/.sequana/pip.yml", "w") as fout:
                 subprocess.call(cmd.split(), stdout=fout)
             logger.debug("Saved your pip environement into pip.txt (conda not found)")
+        else:
+            with open(f"{self.workdir}/.sequana/pip.yml", "w") as fout:
+                fout.write("pip not found")
 
         # General information
 
@@ -641,11 +646,11 @@ class SequanaManager:
                 filename = values[1]
                 Path(filename).unlink()
             logger.critical(
-                "Keep going but your pipeline will probably not be fully executable since images could not be downloaded")
+                "Keep going but your pipeline will probably not be fully executable since images could not be downloaded"
+            )
 
 
 def multiple_downloads(files_to_download, timeout=3600):
-
     async def download(session, url, name, position):
         async with session.get(url, timeout=timeout) as resp:
             with tqdm.wrapattr(
